# Changelog for https://gitlab.com/mbarkhau/myenv

## v201902.0007

 - Packaging updates
 - Better test and mypy coverage


## v201812.0005-beta

 - Add config parsing
 - Simplify instantiation (no need to import myenv to use subclasses)
 - Switch to https://gitlab.com/mbarkhau/myenv
 - Use https://gitlab.com/mbarkhau/bootstrapit


## v201809.0001-beta

 - Initial release
